summaryrefslogtreecommitdiff
path: root/sys/arch/sun3
diff options
context:
space:
mode:
authorArtur Grabowski <art@cvs.openbsd.org>2001-05-05 22:34:36 +0000
committerArtur Grabowski <art@cvs.openbsd.org>2001-05-05 22:34:36 +0000
commit72ef934bda205fc59fa2f5466f78d68301505f95 (patch)
treebae73800529dbab165ac14d49eb97dc0ed1dc685 /sys/arch/sun3
parentb1e2e553c94b439302a1b3bb8500e2cc78896e65 (diff)
Rename configure() to cpu_configure().
Move it from cpu_startup() to main().
Diffstat (limited to 'sys/arch/sun3')
-rw-r--r--sys/arch/sun3/include/cpu.h5
-rw-r--r--sys/arch/sun3/include/machdep.h3
-rw-r--r--sys/arch/sun3/sun3/autoconf.c8
-rw-r--r--sys/arch/sun3/sun3/machdep.c3
4 files changed, 7 insertions, 12 deletions
diff --git a/sys/arch/sun3/include/cpu.h b/sys/arch/sun3/include/cpu.h
index 8194c5b979e..664f4e6f15c 100644
--- a/sys/arch/sun3/include/cpu.h
+++ b/sys/arch/sun3/include/cpu.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: cpu.h,v 1.11 2000/03/02 23:01:45 todd Exp $ */
+/* $OpenBSD: cpu.h,v 1.12 2001/05/05 22:34:21 art Exp $ */
/* $NetBSD: cpu.h,v 1.20 1995/12/21 05:02:10 mycroft Exp $ */
/*
@@ -158,9 +158,6 @@ union sun3sir {
extern unsigned char cpu_machine_id;
-/* autoconf.c */
-void configure __P((void));
-
/* dma.c */
long dvma_kvtopa __P((long, int));
diff --git a/sys/arch/sun3/include/machdep.h b/sys/arch/sun3/include/machdep.h
index a643dd8e7ec..3a650050df8 100644
--- a/sys/arch/sun3/include/machdep.h
+++ b/sys/arch/sun3/include/machdep.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.h,v 1.11 2001/01/03 01:48:07 miod Exp $ */
+/* $OpenBSD: machdep.h,v 1.12 2001/05/05 22:34:22 art Exp $ */
/*
* Copyright (c) 1994 Gordon W. Ross
@@ -87,7 +87,6 @@ int cachectl __P((int req, caddr_t addr, int len));
void child_return __P((void *));
-void configure __P((void));
void cninit __P((void));
void dumpconf __P((void));
diff --git a/sys/arch/sun3/sun3/machdep.c b/sys/arch/sun3/sun3/machdep.c
index df8b8cf0433..d0b3c2955f8 100644
--- a/sys/arch/sun3/sun3/machdep.c
+++ b/sys/arch/sun3/sun3/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.29 2001/05/05 20:56:54 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.30 2001/05/05 22:34:24 art Exp $ */
/* $NetBSD: machdep.c,v 1.77 1996/10/13 03:47:51 christos Exp $ */
/*
@@ -386,7 +386,6 @@ cpu_startup()
printf("kernel does not support -c; continuing..\n");
#endif
}
- configure();
}
/*
diff --git a/sys/arch/sun3/sun3/autoconf.c b/sys/arch/sun3/sun3/autoconf.c
index 7d9c7bc2c23..538fe404ca3 100644
--- a/sys/arch/sun3/sun3/autoconf.c
+++ b/sys/arch/sun3/sun3/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.9 2000/07/14 14:28:56 miod Exp $ */
+/* $OpenBSD: autoconf.c,v 1.10 2001/05/05 22:34:24 art Exp $ */
/* $NetBSD: autoconf.c,v 1.37 1996/11/20 18:57:22 gwr Exp $ */
/*-
@@ -40,7 +40,7 @@
/*
* Setup the system to run on the current machine.
*
* Configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
*/
@@ -69,14 +69,14 @@
int cold;
void
-configure()
+cpu_configure()
{
struct device *mainbus;
/* General device autoconfiguration. */
mainbus = config_rootfound("mainbus", NULL);
if (mainbus == NULL)
- panic("configure: mainbus not found");
+ panic("cpu_configure: mainbus not found");
/* Choose root and swap devices. */
swapgeneric();
@@ -40,7 +40,7 @@
* Setup the system to run on the current machine.
*
- * Configure() is called at boot time. Available
+ * cpu_configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.